@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.104 2006/03/27 21:06:21 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.105 2006/05/01 17:26:26 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -1214,7 +1214,7 @@ do_calctool(int argc, char **argv)
 
     show_display(v->MPdisp_val);     /* Output in correct display mode. */
 
-    memset(&(v->e), 0, sizeof(struct exprm_state)); /* clear expression mode state */
+    memset(&(v->h), 0, sizeof(struct exprm_state_history)); /* clear expression mode state history*/
 
     start_tool();                    /* Display the calculator. */
 }
